package com.bizmatics.system.controller.web;

import com.bizmatics.common.core.bean.ApiResult;
import com.bizmatics.common.core.bean.CommonPage;
import com.bizmatics.common.core.exception.BusinessErrorCode;
import com.bizmatics.model.SysConfig;
import com.bizmatics.service.ISysConfigService;
import com.bizmatics.service.constants.SystemConst;
import com.bizmatics.system.controller.BaseController;
import com.google.protobuf.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 参数配置 信息操作处理
 */
@RestController
@RequestMapping("/config")
public class SysConfigController {
    @Autowired
    private ISysConfigService configService;

    /**
     * 获取参数配置列表
     */
    @GetMapping("/list")
    public ApiResult<List<SysConfig>> list(SysConfig config) {
        return ApiResult.success(configService.selectConfigList(config));
    }

    /**
     * 根据参数编号获取详细信息
     */
    @GetMapping(value = "/{configId}")
    public ApiResult<SysConfig> getInfo(@PathVariable Long configId) {
        return ApiResult.success(configService.selectConfigById(configId));
    }

    /**
     * 根据参数键名查询参数值
     */
    @GetMapping(value = "/configKey/{configKey}")
    public ApiResult<String> getConfigKey(@PathVariable String configKey) {
        return ApiResult.success(configService.selectConfigByKey(configKey));
    }

    /**
     * 新增参数配置
     */
    @PostMapping
    public ApiResult<Integer> add(@Validated @RequestBody SysConfig config) {
        if (SystemConst.NOT_UNIQUE.equals(configService.checkConfigKeyUnique(config))) {
            return ApiResult.error(BusinessErrorCode.BIZ_BUSINESS_ERROR.getCode(), "新增参数'" + config.getConfigName() + "'失败，参数键名已存在");
        }
        return ApiResult.success(configService.insertConfig(config));
    }

    /**
     * 修改参数配置
     */
    @PutMapping
    public ApiResult<Integer> edit(@Validated @RequestBody SysConfig config) {
        if (SystemConst.NOT_UNIQUE.equals(configService.checkConfigKeyUnique(config))) {
            return ApiResult.error(BusinessErrorCode.BIZ_BUSINESS_ERROR.getCode(), "修改参数'" + config.getConfigName() + "'失败，参数键名已存在");
        }

        return ApiResult.success(configService.updateConfig(config));
    }

    /**
     * 删除参数配置
     */
    @DeleteMapping("/{configIds}")
    public ApiResult<Integer> remove(@PathVariable Long[] configIds) {
        return ApiResult.success(configService.deleteConfigByIds(configIds));
    }

    /**
     * 清空缓存
     */
    @DeleteMapping("/clearCache")
    public ApiResult<Void> clearCache() {
        configService.clearCache();
        return ApiResult.success();
    }
}
