package com.bizmatics.system.controller.web;

import com.bizmatics.common.core.bean.ApiResult;
import com.bizmatics.common.core.exception.BusinessErrorCode;

import com.bizmatics.model.SysDictType;
import com.bizmatics.service.ISysDictTypeService;
import com.bizmatics.service.constants.SystemConst;
import com.bizmatics.system.controller.BaseController;
import com.google.protobuf.Api;
import org.springframework.beans.factory.annotation.Autowired;

import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 数据字典信息
 */
@RestController
@RequestMapping("/dict/type")
public class SysDictTypeController extends BaseController {
    @Autowired
    private ISysDictTypeService dictTypeService;

    @GetMapping("/list")
    public ApiResult<List<SysDictType>> list(SysDictType dictType) {
        return ApiResult.success(dictTypeService.selectDictTypeList(dictType));
    }

    /**
     * 查询字典类型详细
     */
    @GetMapping(value = "/{dictId}")
    public ApiResult<SysDictType> getInfo(@PathVariable Long dictId) {
        return ApiResult.success(dictTypeService.selectDictTypeById(dictId));
    }

    /**
     * 新增字典类型
     */
    @PostMapping
    public ApiResult add(@Validated @RequestBody SysDictType dict) {
        if (SystemConst.NOT_UNIQUE.equals(dictTypeService.checkDictTypeUnique(dict))) {
            return ApiResult.error(BusinessErrorCode.BIZ_BUSINESS_ERROR.getCode(), "新增字典'" + dict.getDictName() + "'失败，字典类型已存在");
        }
        return toAjax(dictTypeService.insertDictType(dict));
    }

    /**
     * 修改字典类型
     */
    @PutMapping
    public ApiResult edit(@Validated @RequestBody SysDictType dict) {
        if (SystemConst.NOT_UNIQUE.equals(dictTypeService.checkDictTypeUnique(dict))) {
            return ApiResult.error(BusinessErrorCode.BIZ_BUSINESS_ERROR.getCode(), "修改字典'" + dict.getDictName() + "'失败，字典类型已存在");
        }
        return toAjax(dictTypeService.updateDictType(dict));
    }

    /**
     * 删除字典类型
     */
    @DeleteMapping("/{dictIds}")
    public ApiResult remove(@PathVariable Long[] dictIds) {
        return toAjax(dictTypeService.deleteDictTypeByIds(dictIds));
    }

    /**
     * 清空缓存
     */
    @DeleteMapping("/clearCache")
    public ApiResult clearCache() {
        dictTypeService.clearCache();
        return ApiResult.success();
    }

    /**
     * 获取字典选择框列表
     */
    @GetMapping("/optionselect")
    public ApiResult<List<SysDictType>> optionselect() {
        return ApiResult.success(dictTypeService.selectDictTypeAll());
    }
}
